@@ -9,11 +9,6 @@ pub mod state;
 #[cfg(test)]
 mod test;
 
-#[derive(Debug, PartialEq)]
-pub struct DeviceInfo {
-    device_address: u16,
-}
-
 #[derive(Debug, PartialEq)]
 pub enum Value {
     None,
